summaryrefslogtreecommitdiff
path: root/src/map/mob.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/map/mob.h')
-rw-r--r--src/map/mob.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/map/mob.h b/src/map/mob.h
index f7e071261..458a2d423 100644
--- a/src/map/mob.h
+++ b/src/map/mob.h
@@ -272,14 +272,15 @@ struct item_drop_list {
#define mob_is_treasure(md) (((md)->class_ >= MOBID_TREAS01 && (md)->class_ <= MOBID_TREAS40) || ((md)->class_ >= MOBID_TREAS41 && (md)->class_ <= MOBID_TREAS49))
struct mob_interface {
- //Dynamic mob database, allows saving of memory when there's big gaps in the mob_db [Skotlex]
- struct mob_db *db_data[MAX_MOB_DB+1];
+ // Dynamic mob database, allows saving of memory when there's big gaps in the mob_db [Skotlex]
+ struct mob_db *db_data[MAX_MOB_DB + 1];
struct mob_db *dummy; //Dummy mob to be returned when a non-existant one is requested.
- //Dynamic mob chat database
- struct mob_chat *chat_db[MAX_MOB_CHAT+1];
- //Defines the Manuk/Splendide mob groups for the status reductions [Epoque]
+ // Dynamic mob chat database
+ struct mob_chat *chat_db[MAX_MOB_CHAT + 1];
+ // Defines the Manuk/Splendide/Mora mob groups for the status reductions [Epoque & Frost]
int manuk[8];
int splendide[5];
+ int mora[5];
/* */
int (*init) (bool mimimal);
int (*final) (void);